def calcForce(mass, acceleration):

    """
    Returns force by taking inputs of mass and acceleration
    """

    return mass*acceleration

def calcAttract(gravityConst, mass_1, mass_2, distance):

    """
    Returns the force of attraction between two bodies
    """

    return gravityConst * mass_1 * mass_2 / (distance * distance)

def calcMomentum(mass, velocity):

    """
    Returns the momentum of a body
    """

    return mass * velocity

def calcElecConsume(rating, hoursUsed):

    """
    Returns the electricity consumed by an appliance
    """

    return rating * hoursUsed

def calcHeatConsume(energy, mass, changeTemp):

    """
    Returns the heat consumed by an object
    """

    return energy / (mass * changeTemp)

def calcReflectAngle(incidenceAngle, normalAngle):

    import math

    """
    Returns the reflection angle made by a mirror
    """

    reflectAngle = normalAngle - incidenceAngle

    if reflectAngle < 0:
        reflectAngle = -reflectAngle

    return reflectAngle


import os

def installPackage(Name):

    """
    Install a PIP package
    """

    os.system("pip install " + Name)

def uninstallPackage(Name):

    """
    Uninstalls a PIP package
    """

    os.system("pip uninstall " + Name)

def run(Name):

    """
    Runs a python file
    """

    os.system("python.exe " + Name)

def deleteFile(Name):

    """
    Deletes a file
    """

    os.system("del " + Name)

def changeDir(Path):

    """
    Change directory of command prompt
    """

    os.system("cd " + Path)

def changeDrive(Drive):

    """
    Changes drive of command prompt
    """

    os.system(Drive)

def showDir(Path = ""):

    """
    Shows the content in directory
    """

    os.system("dir " + Path)

def makeDir(Name):

    """
    Make a folder in directory
    """

    os.system("mkdir " + Name)

def command(Cmd):

    """
    Make a command in command prompt
    """

    os.system(Cmd)

def echo(Cmd):

    """
    Make a echo command in command prompt
    """

    os.system("echo " + Cmd)


def writePrime(FileName = "Data", Start_Number = 0, Range_Numbers = None):

        """
        Assign FileName to change the name of Data File\n
        Assign Start_Number to change the number from which Prime Numbers are checked\n
        Assign Range_Numbers to change the number at which checking Prime Numbers are ended\n
        """

        Prime_File = open(FileName + ".txt", "w+")

        while Start_Number <= Range_Numbers:
            writePrime_Raw(Start_Number, Prime_File)
            Start_Number += 1
        
        Prime_File.close()
         
def writePrime_Raw(Max_Range, Prime_File):

        """
        Function to support other Function [NOT TO USE ALONE]
        """

        init_var = 2

        if (Max_Range == init_var):
            Prime_File.write(str(Max_Range) + "\n")

        else:
            while (init_var < Max_Range):
                if (Max_Range % init_var == 0):
                    break
                elif (init_var + 1 == Max_Range):
                    Prime_File.write(str(Max_Range)+ "\n")
                    break
                if (Max_Range / init_var <= init_var):
                    Prime_File.write(str(Max_Range) + "\n")
                    break
                init_var += 1


def isPrime(Number):
        
        """
        Assign value to Number to check if it is a Prime Number
        Returns True if Prime
        """

        init_var = 2
        
        if (Number == init_var):
            return True
        elif (Number == 1 or Number == 0):
            return False
        elif (Number < 0):
            return False
        else:
            while (init_var < Number):
                if (Number % init_var == 0):
                    return False
                elif (init_var + 1 == Number):
                    return True
                if (Number / init_var <= init_var):
                    return True
                init_var += 1


def factors(Number):
    """
    Returns the factors of a number
    """
    all_factors = []
    for init in range(1, (Number + 1)):
        if (Number % init == 0):
            all_factors.append(init)

    return all_factors

def permutation(HeadNumber, BaseNumber):

    """
    Returns the permutation of the inputs
    """

    Product = 1
    Products = 0
    init = HeadNumber

    if (BaseNumber == 0):
        return Product

    while init >= 1:
        Product *= init
        Products += 1

        if (Products == BaseNumber):
            break

        init -= 1

    return Product

def combination(HeadNumber, BaseNumber):

    """
    Returns the combination of the inputs
    """

    Value = permutation(HeadNumber, BaseNumber)

    for number in range(1, BaseNumber + 1):
        Value /= number
    
    return Value

def factorial(Number):
    
    """
    Returns the factorial of the input
    """

    Value = 1

    for number in range(1, Number + 1):
        Value *= number

    return Value

def mean(Numbers):
    
    """
    Returns the mean of an array of values
    """

    Sum = 0
    Number_Elements = 0
    
    try:

        for Element in Numbers:
            Sum += Element
            Number_Elements += 1

        Mean = Sum / Number_Elements
    
        return Mean

    except TypeError:

        print("ERROR: Please assign an array instead of integer!")

        return -1
    
def median(Numbers):

    """
    Returns the median of an array of values
    """

    import math

    try:

        Numbers.sort()

        number_elements = 0
        
        for Element in Numbers:
            number_elements += 1

        Median_Element = (number_elements + 1) / 2

        if (Median_Element % 2 == 0):
            return Numbers[int(Median_Element - 1)]
        
        else:
            FirstElement = Numbers[math.floor(Median_Element - 1)]
            SecondElement = Numbers[math.ceil(Median_Element - 1)]

            FinalElement = (FirstElement + SecondElement) / 2

            return FinalElement
        
    except AttributeError:

        print("ERROR: Please assign an array instead of an integer!")

        return -1
    
def mode(Numbers):

    """
    Returns the mode of an array of values\n
    Returns only one mode of the bi/tri modal data
    """

    try:
        Numbers.sort()
        i = 0
        ModeElement = None
        tempElement = None
        times = 0
        tempTimes = 0

        while i < len(Numbers):
            
            if (ModeElement == None):
                ModeElement = Numbers[i]
                times += 1
            elif (ModeElement == Numbers[i]):
                times += 1
            elif (ModeElement != Numbers[i] and tempElement == Numbers[i]):
                tempElement = Numbers[i]
                tempTimes += 1
            elif (ModeElement != Numbers[i] and tempElement != Numbers[i]):
                tempElement = Numbers [i]
                tempTimes = 1

            if (tempTimes > times):
                ModeElement = tempElement
                times = tempTimes
                tempTimes = 0
                tempElement = None

            i += 1

        return ModeElement

    except AttributeError:
        print("ERROR: Please assign an array instead of an integer!")
        return -1
    
def dataRange(Numbers):
    
    """
    Returns the range of input data
    """

    try:

        MinElement, MaxElement = Numbers[0], Numbers[0]

        for Element in Numbers:

            MinElement = Element if Element < MinElement else MinElement
            MaxElement = Element if Element > MaxElement else MaxElement

        return MaxElement - MinElement
    
    except AttributeError:

        print("ERROR: Please assign an array instead of an integer!")
        return -1

def percentage(value, total):

    """
    Returns the percentage of value
    """

    return value / total * 100

def randomRange(Min, Max):
    import random
    
    """
    Returns a random number between inputs
    """

    return random.randrange(Min, Max)